clear all
close all

Cooling_Temp = 270;    % Temperature of cooling jacket (K)

Flow = 100;            % Volumetric Flowrate (m^3/sec)
V = 100;               % Volume of CSTR (m^3)
rho = 1000;            % Density of A-B Mixture (kg/m^3)
Cp = .239;             % Heat capacity of A-B Mixture (J/kg-K)
mdelH = 5e4;           % Heat of reaction for A->B (J/mol)
                       % E - Activation energy in the 
                       %  Arrhenius Equation (J/mol)
                       % R - Universal Gas Constant 
                       %  = 8.31451 J/mol-K
EoverR = 8750;         % EoverR = E/R
k0 = 7.2e10;           % Pre-exponential factor (1/sec)
                       % U - Overall Heat Transfer 
                       %  Coefficient (W/m^2-K)
                       % A - Area - this value is specific
                       %  for the U calculation (m^2)
                       % UA = U * A
UA = 5e4;
Feed_Conc = 1;         % Feed Concentration (mol/m^3)
Feed_Temp = 350;       % Feed Temperature (K)

Concentration = 0.989;   % Concentration of A in CSTR (mol/m^3)
Ca = Concentration;
Temperature  = 296.6;    % Temperature in CSTR (K)
T = Temperature;

k = k0*exp(-EoverR/T);
rate = k * Ca;

% State Space Model
% dx/dt = A * x + B * u
%     y = C * x + D * u
A = [(-Flow/V-k)          -k*EoverR/T^2;
     (mdelH*k/(rho*Cp))   (-Flow/V-UA/(rho*Cp*V) + mdelH*k/(rho*Cp)*EoverR/T^2)];
B = [(Flow/V)     0       0;
        0      Flow/V  UA/(rho*Cp*V)];
C = [1 0; 0 1];
D = zeros(2,3);

sys = ss(A,B,C,D);
sysd = c2d(sys,0.5);
syss = tf(sys);

step(sys,5);
hold on;
step(sysd,5);
step(syss,5);